@@ -2,8 +2,8 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
 ;; File:         efs-cu.el
-;; Release:      $efs release: 1.19 $
-;; Version:      #Revision: 1.12 $
+;; Release:      $efs release: 1.22 $
+;; Version:      #Revision: 1.13 $
 ;; RCS:          
 ;; Description:  Common utilities needed by efs files.
 ;; Author:       Sandy Rutherford <sandy@ibm550.sissa.it>
@@ -13,7 +13,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;; This file is part of efs. See efs.el for copyright
-;;; (it's copylefted) and warrranty (there isn't one) information.
+;;; (it's copylefted) and warranty (there isn't one) information.
 
 ;;;; Provisions and autoloads.
 
@@ -53,9 +53,9 @@ user's curent login name is used.")
 ;;;; -------------------------------------------------------------
 
 (defconst efs-cu-version
-  (concat (substring "$efs release: 1.19 $" 14 -2)
+  (concat (substring "$efs release: 1.22 $" 14 -2)
 	  "/"
-	  (substring "#Revision: 1.12 $" 11 -2)))
+	  (substring "#Revision: 1.13 $" 11 -2)))
 
 (defconst efs-case-insensitive-host-types
   '(vms cms mts ti-twenex ti-explorer dos mvs tops-20 mpe ka9q dos-distinct
@@ -68,7 +68,7 @@ user's curent login name is used.")
 ;; As well the below two functions depend on the grouping constructs
 ;; in efs-path-regexp. So know what you're doing if you change them.
 
-(defvar efs-path-regexp "^/\\([^@:/]*@\\)?\\([^@:/]*\\):.*"
+(defvar efs-path-regexp "^/\\([^:/]*@\\)?\\([^@:/]*\\):.*"
   "Regexp of a fully expanded remote path.")
 
 (defvar efs-path-format-string "/%s@%s:%s"
@@ -389,7 +389,14 @@ Returns a list (HOST USER PATH), or nil if PATH does not match the format."
   ;; every level, only the bottom level. Therefore, it is not useful for
   ;; obtaining the truename of a file. It is useful for getting at file
   ;; attributes, with a lot less overhead than file truename.
-  (let ((target (file-symlink-p file)))
+
+  ;; `file-symlink-p' just returns nil without running its handler(s)
+  ;; and make-symbolic-link doesn't exist at all on systems that don't
+  ;; support symlinks (ie S_IFLNK is undefined) such as MS Windows with
+  ;; on some Emacsen and XEmacsen.
+  (let ((target (if (efs-ftp-path file)
+		    (efs-file-symlink-p file)
+		  (file-symlink-p file))))
     (if target
 	(efs-chase-symlinks
 	 (expand-file-name target (file-name-directory file)))
