@@ -2,8 +2,8 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
 ;; File:         efs-netrc.el
-;; Release:      $efs release: 1.19 $
-;; Version:      #Revision: 1.3 $
+;; Release:      $efs release: 1.22 $
+;; Version:      #Revision: 1.4 $
 ;; RCS:          
 ;; Description:  Parses ~/.netrc file, and does completion in /.
 ;; Author:       Sandy Rutherford <sandy@ibm550.sissa.it>
@@ -13,7 +13,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;; This file is part of efs. See efs.el for copyright
-;;; (it's copylefted) and warrranty (there isn't one) information.
+;;; (it's copylefted) and warranty (there isn't one) information.
 
 ;;;; ------------------------------------------------------------
 ;;;; Provisions and requirements.
@@ -35,9 +35,9 @@
 ;;;; ------------------------------------------------------------
 
 (defconst efs-netrc-version
-  (concat (substring "$efs release: 1.19 $" 14 -2)
+  (concat (substring "$efs release: 1.22 $" 14 -2)
 	  "/"
-	  (substring "#Revision: 1.2 $" 11 -2)))
+	  (substring "#Revision: 1.4 $" 11 -2)))
 
 ;; Make the byte compiler happy.
 (defvar dired-directory)
@@ -55,7 +55,7 @@ If you have any cryption package running off of find-file-hooks
 (such as crypt.el or crypt++.el), efs will use it to decrypt this file.
 Encrypting this file is a good idea!")
 
-(defvar efs-disable-netrc-security-check nil
+(defvar efs-disable-netrc-security-check (not (eq system-type 'windows-nt))
   "*If non-nil avoid checking permissions for `efs-netrc-filename'.")
 
 ;;;; ------------------------------------------------------------
@@ -311,8 +311,8 @@ information from within."
 	 (modes (nth 8 attr))
 	 (bad-protect (not (string-match ".r..------" modes))))
     (if (or bad-own bad-protect)
-	(save-window-excursion
-	  (with-output-to-temp-buffer "*Help*"
+	(with-output-to-temp-buffer (help-buffer-name nil)
+	  (progn
 	    (if bad-own
 		(princ
 		 (format
@@ -333,9 +333,7 @@ information from within."
 	     "\nIf this is intentional, then setting \
 efs-disable-netrc-security-check
 to t will inhibit this warning in the future.\n"))
-	  (select-window (get-buffer-window "*Help*"))
-	  (enlarge-window (- (count-lines (point-min) (point-max))
-			     (window-height) -1))
+	  (show-temp-buffer-in-current-frame standard-output)
 	  (if (and bad-protect
 		   (y-or-n-p (format "Set permissions on %s to 600? " file)))
 	      (set-file-modes file 384))))))
